<!--
SPDX-FileCopyrightText: 2023 GSI Helmholtzzentrum fuer Schwerionenforschung GmbH, Darmstadt, Germany

SPDX-License-Identifier: LGPL-3.0-only
-->

# py-ina238

[![PyPI](https://img.shields.io/pypi/v/ina238)](https://pypi.org/project/ina238/)

Python driver for the
[Texas Instruments INA238 85-V, 16-Bit, High-Precision Power Monitor With I2C Interface](https://www.ti.com/product/INA238)

## Installation

Latest release:

```bash
pip install ina238
```

## License

Copyright 2023 GSI Helmholtzzentrum fuer Schwerionenforschung GmbH, Darmstadt, Germany

`py-ina238` is distributed under the terms of the
[GNU LGPLv3](https://choosealicense.com/licenses/lgpl-3.0).
